import copy
import os
import unittest

from integration.integration_test_utils import IntegrationTestUtils


class TestEnvSuit(unittest.TestCase):

    TEST_OUT_PATH: str = "not_set"
    TEST_RUN_DATE: str = '20221001'
    TEST_JOB_DIR: str = "SUMMARY_" + TEST_RUN_DATE

    @classmethod
    def setUpClass(cls) -> None:
        TestEnvSuit.write_temp_run_config_file()
        TestEnvSuit.run_advisory_pipeline()


    @staticmethod
    def write_temp_run_config_file():
        nowstring: str = IntegrationTestUtils.get_now_string()
        prefix: str = "temp_advisory_" + nowstring
        # prefix: str = ""

        default_config = IntegrationTestUtils.DEFAULT_CONFIG_FILE_PATH
        default_config_dict: dict = IntegrationTestUtils.load_json_file(default_config)
        run_dict: dict = copy.deepcopy(default_config_dict)
        TestEnvSuit.TEST_OUT_PATH = run_dict['WorkspacePathout'] + prefix + os.sep
        run_dict['WorkspacePathout'] = TestEnvSuit.TEST_OUT_PATH
        run_dict['WorkspacePath'] = TestEnvSuit.TEST_OUT_PATH
        run_dict['ServerName'] = ''  # nothing, as local machine

        IntegrationTestUtils.write_json_file(run_dict, IntegrationTestUtils.TEMP_CONFIG_FILE_PATH)

    @staticmethod
    def run_advisory_pipeline():

        os.environ["EMAIL_CRED"] = "../test_data/test_deployment/envs/Cred_gmail.json"
        from Processor import run_Process, set_log_level
        args_dict: dict = {}
        args_dict['component'] = 'Advisory'
        args_dict['config_paths'] = [IntegrationTestUtils.TEMP_CONFIG_FILE_PATH]
        args_dict['log_level'] = 'info'
        args_dict['live'] = False
        args_dict['start_date'] = '20221001'
        args_dict['noupload'] = True
        set_log_level(args_dict['log_level'])

        IntegrationTestUtils.unpack_zip(IntegrationTestUtils.EXAMPLE_SURVEY_FILE_PATH, TestEnvSuit.TEST_OUT_PATH)
        IntegrationTestUtils.unpack_zip(IntegrationTestUtils.EXAMPLE_DEPO_FILE_PATH, TestEnvSuit.TEST_OUT_PATH)
        IntegrationTestUtils.unpack_zip(IntegrationTestUtils.EXAMPLE_ENV_SUIT_FILE_PATH, TestEnvSuit.TEST_OUT_PATH)

        run_Process(args_dict)

    def test_standard_run_input_status_success(self):
        status_file_path = os.path.join(TestEnvSuit.TEST_OUT_PATH, TestEnvSuit.TEST_JOB_DIR, "STATUS_SUCCESS")
        success_file_exists: bool = os.path.isfile(status_file_path)
        self.assertTrue(success_file_exists)

    def test_standard_run_input_all_docs_produced(self):

        east_africa_image_path = os.path.join(TestEnvSuit.TEST_OUT_PATH, TestEnvSuit.TEST_JOB_DIR,
                                              "tight-layout",
                                              "wheat_rust_advisory_template_EastAfrica_20221001.docx")
        ethiopia_image_path = os.path.join(TestEnvSuit.TEST_OUT_PATH, TestEnvSuit.TEST_JOB_DIR,
                                           "tight-layout",
                                           "wheat_rust_advisory_template_Ethiopia_20221001.docx")

        ea_file_exists: bool = os.path.isfile(east_africa_image_path)
        eth_file_exists: bool = os.path.isfile(ethiopia_image_path)
        self.assertTrue(ea_file_exists)
        self.assertTrue(eth_file_exists)


if __name__ == '__main__':
    unittest.main()
